"use strict";

exports.CapeType = exports.CapeName = exports.CapeHash = exports.CapeContext = void 0;

var _context = require("./context");

var _utils = require("../utils");

/**
 * Cape types
 */
var CapeType;
exports.CapeType = CapeType;

(function (CapeType) {
  CapeType["MINECRAFT"] = "minecraft";
  CapeType["OPTIFINE"] = "optifine";
})(CapeType || (exports.CapeType = CapeType = {}));
/**
 * Capes names
 */


var CapeName;
exports.CapeName = CapeName;

(function (CapeName) {
  CapeName["MINECON_2016"] = "MineCon 2016";
  CapeName["MINECON_2015"] = "MineCon 2015";
  CapeName["MINECON_2013"] = "MineCon 2013";
  CapeName["MINECON_2012"] = "MineCon 2012";
  CapeName["MINECON_2011"] = "MineCon 2011";
  CapeName["REALMS_MAPMAKER"] = "Realms Mapmaker";
  CapeName["MOJANG"] = "Mojang";
  CapeName["MOJANG_CLASSIC"] = "Mojang (Classic)";
  CapeName["TRANSLATOR"] = "Translator";
  CapeName["TRANSLATOR_CHINESE"] = "Translator (Chinese)";
  CapeName["TRANSLATOR_JAPANESE"] = "Translator (Japanese)";
  CapeName["MOJIRA_MODERATOR"] = "Mojira Moderator";
  CapeName["COBALT"] = "Cobalt";
  CapeName["SCROLLS"] = "Scrolls";
  CapeName["DB"] = "dB";
  CapeName["SNOWMAN"] = "Snowman";
  CapeName["MILLIONTH_CUSTOMER"] = "Millionth Customer";
  CapeName["SPADE"] = "Spade";
  CapeName["PRISMARINE"] = "Prismarine";
  CapeName["TURTLE"] = "Turtle";
  CapeName["BIRTHDAY"] = "Birthday";
  CapeName["MIGRATOR"] = "Migrator";
  CapeName["MOJANG_STUDIOS"] = "Mojang Studios";
  CapeName["OPTIFINE"] = "Optifine";
})(CapeName || (exports.CapeName = CapeName = {}));
/**
 * Capes hashes
 */


var CapeHash;
exports.CapeHash = CapeHash;

(function (CapeHash) {
  CapeHash["MINECON_2016"] = "1981aad373fa9754";
  CapeHash["MINECON_2015"] = "72ee2cfcefbfc081";
  CapeHash["MINECON_2013"] = "0e4cc75a5f8a886d";
  CapeHash["MINECON_2012"] = "ebc798c3f7eca2a3";
  CapeHash["MINECON_2011"] = "9349fa25c64ae935";
  CapeHash["REALMS_MAPMAKER"] = "11a3dcc4d826d0a1";
  CapeHash["MOJANG"] = "cb5dd34bee340182";
  CapeHash["MOJANG_CLASSIC"] = "298ae017a64261ad";
  CapeHash["TRANSLATOR"] = "129a4675704fa3b8";
  CapeHash["TRANSLATOR_CHINESE"] = "d059f1a18b159eb6";
  CapeHash["TRANSLATOR_JAPANESE"] = "aa02d4b62762ff22";
  CapeHash["MOJIRA_MODERATOR"] = "8dd71c1ee6ec0ae4";
  CapeHash["COBALT"] = "696b6cc29946b968";
  CapeHash["SCROLLS"] = "116bacd62b233157";
  CapeHash["DB"] = "77421d9cf72e07e9";
  CapeHash["SNOWMAN"] = "5e68fa78bd9df310";
  CapeHash["MILLIONTH_CUSTOMER"] = "d3c7ac835b24eb29";
  CapeHash["SPADE"] = "7a939dc1a7ad4505";
  CapeHash["PRISMARINE"] = "88f1509813f4e324";
  CapeHash["TURTLE"] = "8c05ef3c54870d04";
  CapeHash["MIGRATOR"] = "8a6cc02cc86e43f1";
  CapeHash["BIRTHDAY"] = "aab5a23c7495fc70";
  CapeHash["MOJANG_STUDIOS"] = "c00df589ebea3ad6";
})(CapeHash || (exports.CapeHash = CapeHash = {}));

class CapeContext extends _context.Context {
  /**
   * @hidden
   */
  constructor({
    hash,
    ...options
  }) {
    super(options);
    /**
     * @hidden
     */

    this.endpoint = this.options.getEndpoint();
    this.hash = hash;
  }
  /**
   * Get cape url
   */


  get url() {
    return `${this.endpoint}/texture/${this.hash}.png`;
  }
  /**
   * Get cape type
   */


  get type() {
    return Object.values(CapeHash).includes(this.hash) ? CapeType.MINECRAFT : CapeType.OPTIFINE;
  }
  /**
   * Get cape name
   */


  get name() {
    const cape = new Map(Object.entries(CapeHash).map(entry => entry.reverse())).get(this.hash);

    if (cape) {
      const capeName = new Map(Object.entries(CapeName)).get(cape);
      return capeName;
    }

    return CapeName.OPTIFINE;
  }
  /**
   * Check is Minecraft cape
   */


  get isMinecraft() {
    return this.type === CapeType.MINECRAFT;
  }
  /**
   * Check is Optifine cape
   */


  get isOptifine() {
    return this.type === CapeType.OPTIFINE;
  }
  /**
   * @hidden
   */


  [_utils.kSerializeData]() {
    return (0, _utils.pickProperties)(this, ['hash', 'url', 'name', 'type']);
  }

}

exports.CapeContext = CapeContext;