import * as cheerio from 'cheerio';
import { Context, IContextOptions } from './context';
import { SkinContext } from './skin';
import { PlayerContext } from './player';
import { ServerContext } from './server';
import { kSerializeData } from '../utils';
export interface ISearchContextOptions extends IContextOptions {
    data?: string | cheerio.Element | cheerio.Element[];
}
/**
 * NameMC Search Name Status
 */
export declare enum NameStatus {
    AVAILABLE = "available",
    AVAILABLE_LATER = "available_later",
    UNAVAILABLE = "unavailable",
    INVALID = "invalid"
}
export declare type NameStatusUnion = `${NameStatus}`;
export declare class SearchContext extends Context<SearchContext> {
    /**
     * Search Query
     */
    readonly query: string;
    /**
     * Query name info
     */
    readonly name: {
        /**
         * Name status
         */
        status: "invalid" | NameStatus | "available" | "available_later" | "unavailable";
        /**
         * Name availability timestamp
         */
        availabilityTime: number | null;
        /**
         * Name availability time
         */
        availabilityAt: number | null;
        /**
         * Name searches
         */
        searches: number;
    };
    /**
     * Query players
     */
    readonly players: PlayerContext[];
    /**
     * Query servers
     */
    readonly servers: ServerContext[];
    /**
     * Query skin tag
     */
    readonly skin: SkinContext | null;
    /**
     * @hidden
     */
    constructor({ data, ...options }: ISearchContextOptions);
    /**
     * Check is query name is available
     */
    get isAvailable(): boolean;
    /**
     * Check is query name is available available later
     */
    get isAvailableLater(): boolean;
    /**
     * Check is query name is unavailable
     */
    get isUnavailable(): boolean;
    /**
     * Check is query name is invalid
     */
    get isInvalid(): boolean;
    /**
     * Check query has players
     */
    get hasPlayers(): boolean;
    /**
     * Check query has servers
     */
    get hasServers(): boolean;
    /**
     * Check query has skin tag name
     */
    get hasSkinTag(): boolean;
    /**
     * @hidden
     */
    [kSerializeData](): any;
}
